@@ -1,16 +1,16 @@
-use clap::Clap;
+use clap::Parser;
 use eternalfest_core::types::AnyError;
 use eternalfest_db_schema::SchemaStateRef;
 use sqlx::postgres::{PgConnectOptions, PgPoolOptions};
 use sqlx::PgPool;
 
-#[derive(Debug, Clap)]
+#[derive(Debug, Parser)]
 pub struct DbArgs {
   #[clap(subcommand)]
   command: DbCommand,
 }
 
-#[derive(Debug, Clap)]
+#[derive(Debug, Parser)]
 pub enum DbCommand {
   /// Check the state of the database
   #[clap(name = "check")]
