@@ -1,7 +1,7 @@
 use crate::cmd::clean::CleanArgs;
 use crate::cmd::db::DbArgs;
 use crate::cmd::dump::DumpArgs;
-use clap::Clap;
+use clap::Parser;
 use eternalfest_core::types::AnyError;
 
 pub mod cmd {
@@ -10,14 +10,14 @@ pub mod cmd {
   pub mod dump;
 }
 
-#[derive(Debug, Clap)]
+#[derive(Debug, Parser)]
 #[clap(author = "Eternaltwin")]
 pub struct CliArgs {
   #[clap(subcommand)]
   command: CliCommand,
 }
 
-#[derive(Debug, Clap)]
+#[derive(Debug, Parser)]
 pub enum CliCommand {
   #[clap(name = "clean")]
   Clean(CleanArgs),
