@@ -1,4 +1,4 @@
-use clap::Clap;
+use clap::Parser;
 use eternalfest_cli::{run, CliArgs};
 
 #[tokio::main]
